package solatium;

import org.junit.*;
import solatium.auth.Verification;
import solatium.blockchain.BlockChain;
import solatium.blockchain.Chain;
import solatium.interfaces.Customer;
import solatium.interfaces.DataBase;
import solatium.interfaces.User;

import static org.junit.Assert.*;

public class VerificationTest {

    private static final Chain BLOCK_CHAIN = new BlockChain();

    @Test
    public void shouldVerifyRightUser() {
        String password = "password";
        String username = "username";
        String address = "Addresse";
        User user = new Customer(username, password, address, 0, BLOCK_CHAIN);
        Verification verify = new Verification(new FakerUserDataBase(user));

        assertTrue(verify.verifiy(username, password));
    }

    @Test
    public void shouldVerifyWrongPassword() {
        String password = "password";
        String username = "username";
        String address = "Addresse";
        String wrongPassword = "foobar";
        User user = new Customer(username, password, address, 0, BLOCK_CHAIN);
        Verification verify = new Verification(new FakerUserDataBase(user));

        assertFalse(verify.verifiy(username, wrongPassword));
    }

    @Test
    public void shouldVerifyBlockedUser() {
        String password = "password";
        String username = "username";
        String address = "Addresse";
        User user = new Customer(username, password, address, 3, BLOCK_CHAIN);
        Verification verify = new Verification(new FakerUserDataBase(user));

        assertFalse(verify.verifiy(username, password));
    }

    @Test
    public void shouldVerifyPasswordNull() {
        String password = null;
        String username = "username";
        String address = "Address";
        User user = new Customer(username, password, address, 0, BLOCK_CHAIN);
        Verification verify = new Verification(new FakerUserDataBase(user));

        assertFalse(verify.verifiy(username, password));
    }

    @Test
    public void shouldVerifyUsernameNull() {
        String password = "password";
        String username = null;
        String address = "Address";
        User user = new Customer(username, password, address,0, BLOCK_CHAIN);
        Verification verify = new Verification(new FakerUserDataBase(user));

        assertFalse(verify.verifiy(username, password));
    }

    @Test
    public void shouldVerifyUserNull() {
        String password = "password";
        String username = "username";
        User user = null;
        Verification verify = new Verification(new FakerUserDataBase(user));

        assertFalse(verify.verifiy(username, password));
    }

    private class FakerUserDataBase implements DataBase {
        private final User user;

        private FakerUserDataBase(User user) {
            this.user = user;
        }

        @Override
        public User getUser(String userName) {
            return user;
        }
    }
}
